@@ -57,7 +57,7 @@ class LSldapObject {
    *
    * @retval boolean true si l'objet a Ã©tÃ© construit, false sinon.
    */ 
-  function LSldapObject() {
+  public function __construct() {
     $this -> type_name = get_class($this);
     $config = LSconfig :: get('LSobjects.'.$this -> type_name);
     if(is_array($config)) {
@@ -68,7 +68,7 @@ class LSldapObject {
       return;
     }
     
-    foreach($this -> config['attrs'] as $attr_name => $attr_config) {
+    foreach($this -> getConfig('attrs', array()) as $attr_name => $attr_config) {
       if(!$this -> attrs[$attr_name]=new LSattribute($attr_name,$attr_config,$this)) {
         return;
       }
@@ -89,7 +89,7 @@ class LSldapObject {
    *
    * @retval boolean true si la chargement a rÃ©ussi, false sinon.
    */ 
-  function loadData($dn) {
+  public function loadData($dn) {
     $this -> dn = $dn;
     $data = LSldap :: getAttrs($dn);
     if(!empty($data)) {
@@ -110,7 +110,7 @@ class LSldapObject {
    *
    * @retval boolean true si la rechargement a rÃ©ussi, false sinon.
    */ 
-  function reloadData() {
+  public function reloadData() {
     $data = LSldap :: getAttrs($this -> dn);
     foreach($this -> attrs as $attr_name => $attr) {
       if(!$this -> attrs[$attr_name] -> reloadData( (isset($data[$attr_name])?$data[$attr_name]:NULL) ))
@@ -126,8 +126,8 @@ class LSldapObject {
    *
    * @retval string Format d'affichage de l'objet.
    */ 
-  function getDisplayNameFormat() {
-    return $this -> config['display_name_format'];
+  public function getDisplayNameFormat() {
+    return $this -> getConfig('display_name_format');
   }
   
   /**
@@ -144,7 +144,7 @@ class LSldapObject {
    *
    * @retval string Valeur descriptive d'affichage de l'objet
    */ 
-  function getDisplayName($spe='',$full=false) {
+  public function getDisplayName($spe='',$full=false) {
     if ($spe=='') {
       $spe = $this -> getDisplayNameFormat();
     }
@@ -167,7 +167,7 @@ class LSldapObject {
    *
    * @retval string Valeur d'une chaine formatÃ©e
    */ 
-  function getFData($format) {
+  public function getFData($format) {
     $format=getFData($format,$this,'getValue');
     return $format;
   }
@@ -184,7 +184,7 @@ class LSldapObject {
    *
    * @retval string Valeur d'une chaine formatee
    */
-  function getDisplayFData($format) {
+  public function getDisplayFData($format) {
     return getFData($format,$this,'getDisplayValue');
   }
   
@@ -201,7 +201,7 @@ class LSldapObject {
    *
    * @retval LSform Le formulaire crÃ©e
    */ 
-  function getForm($idForm,$load=NULL) {
+  public function getForm($idForm,$load=NULL) {
     LSsession :: loadLSclass('LSform');
     $LSform = new LSform($this,$idForm);
     $this -> forms[$idForm] = array($LSform,$load);
@@ -244,7 +244,7 @@ class LSldapObject {
    *
    * @retval LSform Le formulaire crÃ©e
    */ 
-  function getView() {
+  public function getView() {
     LSsession :: loadLSclass('LSform');
     $this -> view = new LSform($this,'view');
     foreach($this -> attrs as $attr_name => $attr) {
@@ -265,7 +265,7 @@ class LSldapObject {
    *
    * @retval boolean true sile formulaire a Ã©tÃ© rafraichis, false sinon
    */ 
-  function refreshForm($idForm) {
+  public function refreshForm($idForm) {
     $LSform = $this -> forms[$idForm][0];
     foreach($this -> attrs as $attr_name => $attr) {
       if(!$this -> attrs[$attr_name] -> refreshForm($LSform,$idForm)) {
@@ -395,7 +395,7 @@ class LSldapObject {
    *
    * @retval boolean true si les donnÃ©es sont valides, false sinon
    */ 
-  function validateAttrsData($idForm=null) {
+  public function validateAttrsData($idForm=null) {
     $retval = true;
     if ($idForm) {
       $LSform=$this -> forms[$idForm][0];
@@ -403,7 +403,7 @@ class LSldapObject {
     else {
       $LSform=false;
     }
-    foreach($this -> attrs as $attr) {
+    foreach($this -> attrs as $attr_name => $attr) {
       $attr_values = $attr -> getValue();
       if (!$attr -> isValidate()) {
         if($attr -> isUpdate()) {
@@ -425,6 +425,10 @@ class LSldapObject {
             }
           }
           else {
+            // Don't blame on non-create form for attributes not-present in form (or freezed)
+            if ($LSform && $idFrom != 'create' && (!$LSform -> hasElement($attr_name) || $LSform -> isFreeze($attr_name)))
+              continue;
+
             LSerror :: addErrorCode('LSattribute_06',$attr -> getLabel());
             $retval = false;
           }
@@ -444,7 +448,7 @@ class LSldapObject {
    *
    * @retval boolean true si les donnÃ©es sont valides, false sinon
    */
-  function validateAttrData(&$LSform,&$attr) {
+  public function validateAttrData(&$LSform,&$attr) {
     $retval = true;
     
     $vconfig=$attr -> getValidateConfig();
@@ -486,7 +490,7 @@ class LSldapObject {
               $sfilter_user=NULL;
             }
             if(isset($test['object_type']) && LSsession :: loadLSobject($test['object_type']) ) {
-              $sfilter=self :: getObjectFilter($test['object_type']);
+              $sfilter=self :: _getObjectFilter($test['object_type']);
 
               if ($sfilter_user) {
                 $sfilter=LSldap::combineFilters('and',array($sfilter_user,$sfilter));
@@ -580,12 +584,12 @@ class LSldapObject {
    *
    * @retval boolean true si la mise Ã  jour a rÃ©ussi, false sinon
    */ 
-  function submitChange($idForm) {
+  public function submitChange($idForm) {
     $submitData=array();
     $new = $this -> isNew();
     foreach($this -> attrs as $attr) {
       if(($attr -> isUpdate())&&($attr -> isValidate())) {
-        if(($attr -> name == $this -> config['rdn'])&&(!$new)) {
+        if(($attr -> name == $this -> getConfig('rdn')) && (!$new)) {
           $new = true;
           LSdebug('Rename');
           if (!$this -> fireEvent('before_rename')) {
@@ -601,6 +605,10 @@ class LSldapObject {
             }
             $this -> dn = $newDn;
             $this -> oldDn = $oldDn;
+
+            // PHP Net_LDAP2 does not remove old RDN value : replace RDN value
+            $submitData[$attr -> name] = $attr -> getUpdateData();
+
             if (!$this -> fireEvent('after_rename')) {
               LSerror :: addErrorCode('LSldapObject_17');
               return;
@@ -670,7 +678,7 @@ class LSldapObject {
    *                  - [0] : le premier paramÃ¨tre
    *                  - [1] : les paramÃ¨tres suivants
    */ 
-  function getDnInfos($dn) {
+  public static function getDnInfos($dn) {
     $infos=ldap_explode_dn($dn,0);
     if(!$infos)
       return;
@@ -684,6 +692,17 @@ class LSldapObject {
         $basedn.=','.$infos[$i];
     return array($infos[0],$basedn);
   }
+
+  /**
+   * Retourne le filtre correpondants aux objetcClass de l'objet courant
+   *
+   * @author Benjamin Renard <brenard@easter-eggs.com>
+   *
+   * @retval Net_LDAP2_Filter le filtre ldap correspondant au type de l'objet
+   */
+  public function getObjectFilter() {
+    return self :: getObjectFilter($this -> type_name);
+  }
   
   /**
    * Retourne le filtre correpondants aux objetcClass de l'objet
@@ -692,10 +711,7 @@ class LSldapObject {
    *
    * @retval Net_LDAP2_Filter le filtre ldap correspondant au type de l'objet
    */ 
-  function getObjectFilter($type=null) {
-    if (is_null($type)) {
-      $type = $this -> type_name;
-    }
+  public static function _getObjectFilter($type) {
     $oc=LSconfig::get("LSobjects.$type.objectclass");
     if(!is_array($oc)) return;
     $filters=array();
@@ -725,7 +741,7 @@ class LSldapObject {
    *
    * @retval string le filtre ldap correspondant
    */ 
-  function getPatternFilter($pattern=null,$approx=null) {
+  public function getPatternFilter($pattern=null,$approx=null) {
     if ($pattern) {
       $search = new LSsearch($this -> type_name, 'LSldapObject', array('approx' => (bool)$approx));
       $filter = $search -> getFilterFromPattern($pattern);
@@ -750,7 +766,7 @@ class LSldapObject {
    *
    * @retval array Tableau d'objets correspondant au resultat de la recherche
    */ 
-  function listObjects($filter=NULL,$basedn=NULL,$params=array()) {
+  public function listObjects($filter=NULL,$basedn=NULL,$params=array()) {
     if (!LSsession :: loadLSclass('LSsearch')) {
       LSerror::addErrorCode('LSsession_05','LSsearch');
       return;
@@ -786,7 +802,7 @@ class LSldapObject {
    *
    * @retval array Tableau dn => name correspondant au resultat de la recherche
    */ 
-  function listObjectsName($filter=NULL,$sbasedn=NULL,$sparams=array(),$displayFormat=false,$cache=true) {
+  public function listObjectsName($filter=NULL,$sbasedn=NULL,$sparams=array(),$displayFormat=false,$cache=true) {
     if (!LSsession :: loadLSclass('LSsearch')) {
       LSerror::addErrorCode('LSsession_05','LSsearch');
       return;
@@ -828,9 +844,9 @@ class LSldapObject {
    * 
    * @retval array Tableau d'objets correspondant au resultat de la recherche
    */
-  function searchObject($name,$basedn=NULL,$filter=NULL,$params=NULL) {
+  public function searchObject($name,$basedn=NULL,$filter=NULL,$params=NULL) {
     if (!$filter) {
-      $filter = '('.$this -> config['rdn'].'='.$name.')';
+      $filter = '('.$this -> getConfig('rdn').'='.$name.')';
     }
     else {
       $filter = getFData($filter,$name);
@@ -855,7 +871,7 @@ class LSldapObject {
    *
    * @retval mixed la valeur demandÃ© ou ' ' si celle-ci est inconnue.
    */ 
-  function getValue($val) {
+  public function getValue($val) {
     if(($val=='dn')||($val=='%{dn}')) {
       return $this -> dn;
     }
@@ -891,7 +907,7 @@ class LSldapObject {
    *
    * @retval mixed la valeur demandee ou ' ' si celle-ci est inconnue.
    */
-  function getDisplayValue($val) {
+  public function getDisplayValue($val) {
     if(isset($this ->  attrs[$val])){
       if (method_exists($this ->  attrs[$val],'getDisplayValue'))
         return $this -> attrs[$val] -> getDisplayValue();
@@ -911,7 +927,7 @@ class LSldapObject {
    *
    * @retval void
    **/
-  function registerOtherValue($name,$value) {
+  public function registerOtherValue($name,$value) {
     $this -> other_values[$name]=$value;
   }
 
@@ -922,7 +938,7 @@ class LSldapObject {
    *
    * @retval array('dn' => 'display')
    */
-  function getSelectArray($pattern=NULL,$topDn=NULL,$displayFormat=NULL,$approx=false,$cache=true,$filter=NULL,$sparams=array()) {
+  public function getSelectArray($pattern=NULL,$topDn=NULL,$displayFormat=NULL,$approx=false,$cache=true,$filter=NULL,$sparams=array()) {
     $sparams['pattern']=$pattern;
     return $this -> listObjectsName($filter,$topDn,$sparams,$displayFormat,$cache);
   }
@@ -937,21 +953,21 @@ class LSldapObject {
    *
    * @retval string Le DN de l'objet
    */   
-  function getDn() {
+  public function getDn() {
     if($this -> dn) {
       return $this -> dn;
     }
     else {
       $container_dn=$this -> getContainerDn();
       if ($container_dn) {
-        $rdn_attr=$this -> config['rdn'];
-        if( (isset($this -> config['rdn'])) && (isset($this -> attrs[$rdn_attr])) ) {
+        $rdn_attr = $this -> getConfig('rdn');
+        if( $rdn_attr && isset($this -> attrs[$rdn_attr]) ) {
           $rdn_val=$this -> attrs[$rdn_attr] -> getUpdateData();
           if (!empty($rdn_val)) {
             return $rdn_attr.'='.$rdn_val[0].','.$container_dn;
           }
           else {
-            LSerror :: addErrorCode('LSldapObject_12',$this -> config['rdn']);
+            LSerror :: addErrorCode('LSldapObject_12', $rdn_attr);
             return;
           }
         }
@@ -973,12 +989,14 @@ class LSldapObject {
    *
    * @retval string Le container DN de l'objet
    */
-  function getContainerDn() {
+  public function getContainerDn() {
     $topDn = LSsession :: getTopDn();
-    if (isset($this -> config['generate_container_dn'])) {
-      if (is_callable($this -> config['generate_container_dn'])) {
+    $generate_container_dn = $this -> getConfig('generate_container_dn');
+    $container_dn = $this -> getConfig('container_dn');
+    if ($generate_container_dn) {
+      if (is_callable($generate_container_dn)) {
         try {
-          $container_dn=$this -> config['generate_container_dn']($this);
+          $container_dn = call_user_func_array($generate_container_dn, array(&$this));
           return $container_dn.','.$topDn;
         }
         catch (Exception $e) {
@@ -986,11 +1004,11 @@ class LSldapObject {
         }
       }
       else {
-        LSerror :: addErrorCode('LSldapObject_33',$this -> config['generate_container_dn']);
+        LSerror :: addErrorCode('LSldapObject_33', $generate_container_dn);
       }
     }
-    else if ((isset($this -> config['container_dn'])) && ($topDn)) {
-      return $this -> config['container_dn'].','.$topDn;
+    else if ($container_dn && $topDn) {
+      return $container_dn.','.$topDn;
     }
     else {
       LSerror :: addErrorCode('LSldapObject_11',$this -> getType());
@@ -1006,7 +1024,7 @@ class LSldapObject {
    * 
    * @retval string Le type de l'objet ($this -> type_name)
    */
-  function getType() {
+  public function getType() {
     return $this -> type_name;
   }
   
@@ -1017,7 +1035,7 @@ class LSldapObject {
    * 
    * @retval string 'admin'/'self'/'user' pour Admin , l'utilisateur lui mÃªme ou un simple utilisateur
    */
-  function whoami() {
+  public function whoami() {
     if (!$this -> _whoami)
       $this -> _whoami = LSsession :: whoami($this -> dn);
     return $this -> _whoami;
@@ -1030,7 +1048,7 @@ class LSldapObject {
    * 
    * @retval string Le label de l'objet ($this -> config['label'])
    */
-  function getLabel($type=null) {
+  public function getLabel($type=null) {
     if (is_null($type)) {
       $type = $this -> type_name;
     }
@@ -1045,7 +1063,7 @@ class LSldapObject {
    * 
    * @retval boolean True si l'objet Ã  Ã©tÃ© supprimÃ©, false sinon
    */
-  function remove() {
+  public function remove() {
     if ($this -> fireEvent('before_delete')) {
       if (LSldap :: remove($this -> getDn())) {
         if ($this -> fireEvent('after_delete')) {
@@ -1067,7 +1085,7 @@ class LSldapObject {
    * 
    * @retval boolean True si l'objet est nouveau, false sinon
    */
-  function isNew() {
+  public function isNew() {
     return (!$this -> dn);
   }
 
@@ -1108,13 +1126,14 @@ class LSldapObject {
    * 
    * @retval True en cas de cas ce succès, False sinon.
    */
-  function updateLSrelationsCache() {
+  private function updateLSrelationsCache() {
     $this -> _LSrelationsCache=array();
-    if (is_array($this->config['LSrelation']) && LSsession :: loadLSclass('LSrelation')) {
+    $LSrelations = $this -> getConfig('LSrelation');
+    if (is_array($LSrelations) && LSsession :: loadLSclass('LSrelation')) {
       $type = $this -> getType();
       $me = new $type();
       $me -> loadData($this -> getDn());
-      foreach($this->config['LSrelation'] as $relation_name => $relation_conf) {
+      foreach($LSrelations as $relation_name => $relation_conf) {
         $relation = new LSrelation($me, $relation_name);
         $list = $relation -> listRelatedObjects();
         if (is_array($list)) {
@@ -1141,7 +1160,7 @@ class LSldapObject {
    * 
    * @retval True en cas de cas ce succès, False sinon.
    */
-  function beforeRename() {
+  private function beforeRename() {
     // LSrelations
     return $this -> updateLSrelationsCache();
   }
@@ -1155,7 +1174,7 @@ class LSldapObject {
    * 
    * @retval True en cas de cas ce succès, False sinon.
    */
-  function afterRename() {
+  private function afterRename() {
     $error = 0;
     
     // Change LSsession -> userObject Dn
@@ -1186,7 +1205,7 @@ class LSldapObject {
    * 
    * @retval True en cas de cas ce succès, False sinon.
    */
-  function beforeDelete() {
+  private function beforeDelete() {
     $return = $this -> updateLSrelationsCache();
     
     foreach(array_keys($this -> attrs) as $attr_name) {
@@ -1207,7 +1226,7 @@ class LSldapObject {
    * 
    * @retval True en cas de cas ce succès, False sinon.
    */
-  function afterDelete() {
+  private function afterDelete() {
     $error = 0;
     
     // LSrelations
@@ -1247,7 +1266,7 @@ class LSldapObject {
    * 
    * @retval True en cas de cas ce succès, False sinon.
    */
-  function afterCreate() {
+  private function afterCreate() {
     LSdebug('after');
     $error = 0;
     
@@ -1295,7 +1314,7 @@ class LSldapObject {
    * 
    * @retval True en cas de cas ce succès, False sinon.
    */
-  function afterModify() {
+  private function afterModify() {
     $error = 0;
     
     // LSsearch : Purge LSobject cache
@@ -1317,7 +1336,7 @@ class LSldapObject {
    * 
    * @retval Mixed La valeur clef d'un objet en relation
    **/
-  function getObjectKeyValueInRelation($object,$objectType,$attrValues='dn') {
+  public static function getObjectKeyValueInRelation($object,$objectType,$attrValues='dn') {
     if (!$objectType) {
       LSerror :: addErrorCode('LSrelations_05','getObjectKeyValueInRelation');
       return;
@@ -1359,7 +1378,7 @@ class LSldapObject {
    * 
    * @retval Array of $objectType Les objets en relations
    **/
-  function listObjectsInRelation($object,$attr,$objectType,$attrValues='dn') {
+  public function listObjectsInRelation($object,$attr,$objectType,$attrValues='dn') {
     if ((!$attr)||(!$objectType)) {
       LSerror :: addErrorCode('LSrelations_05','listObjectsInRelation');
       return;
@@ -1392,7 +1411,7 @@ class LSldapObject {
    * 
    * @retval boolean true si l'objet à été ajouté, False sinon
    **/  
-  function addOneObjectInRelation($object,$attr,$objectType,$attrValue='dn',$canEditFunction=NULL) {
+  public function addOneObjectInRelation($object,$attr,$objectType,$attrValue='dn',$canEditFunction=NULL) {
     if ((!$attr)||(!$objectType)) {
       LSerror :: addErrorCode('LSrelations_05','addOneObjectInRelation');
       return;
@@ -1457,7 +1476,7 @@ class LSldapObject {
    * 
    * @retval boolean true si l'objet à été supprimé, False sinon
    **/  
-  function deleteOneObjectInRelation($object,$attr,$objectType,$attrValue='dn',$canEditFunction=NULL,$attrValues=null) {
+  public function deleteOneObjectInRelation($object,$attr,$objectType,$attrValue='dn',$canEditFunction=NULL,$attrValues=null) {
     if ((!$attr)||(!$objectType)) {
       LSerror :: addErrorCode('LSrelations_05','deleteOneObjectInRelation');
       return;
@@ -1508,7 +1527,7 @@ class LSldapObject {
   *  
   * @retval boolean True en cas de succès, False sinon
   */
-  function renameOneObjectInRelation($object,$oldValues,$attr,$objectType,$attrValue='dn') {
+  public function renameOneObjectInRelation($object,$oldValues,$attr,$objectType,$attrValue='dn') {
     if ((!$attr)||(!$objectType)) {
       LSerror :: addErrorCode('LSrelations_05','renameOneObjectInRelation');
       return;
@@ -1564,7 +1583,7 @@ class LSldapObject {
    * 
    * @retval boolean true si tout c'est bien passé, False sinon
    **/  
-  function updateObjectsInRelation($object,$listDns,$attr,$objectType,$attrValue='dn',$canEditFunction=NULL,$attrValues=null) {
+  public function updateObjectsInRelation($object,$listDns,$attr,$objectType,$attrValue='dn',$canEditFunction=NULL,$attrValues=null) {
     if ((!$attr)||(!$objectType)) {
       LSerror :: addErrorCode('LSrelations_05','updateObjectsInRelation');
       return;
@@ -1612,7 +1631,7 @@ class LSldapObject {
    * 
    * @retval void
    */
-  function addEvent($event,$fct,$param=NULL,$class=NULL) {
+  public function addEvent($event,$fct,$param=NULL,$class=NULL) {
     $this -> _events[$event][] = array(
       'function'  => $fct,
       'param'    => $param,
@@ -1630,7 +1649,7 @@ class LSldapObject {
    * 
    * @retval void
    */
-  function addObjectEvent($event,&$obj,$meth,$param=NULL) {
+  public function addObjectEvent($event,&$obj,$meth,$param=NULL) {
     $this -> _objectEvents[$event][] = array(
       'obj'  => &$obj,
       'meth'  => $meth,
@@ -1645,22 +1664,19 @@ class LSldapObject {
    * 
    * @retval boolean True si tout c'est bien passé, false sinon
    */
-  function fireEvent($event) {
+  public function fireEvent($event) {
     
     // Object event
     $return = $this -> fireObjectEvent($event);
     
     // Config
-    if(isset($this -> config[$event])) {
-      if (!is_array($this -> config[$event])) {
+    $funcs = $this -> getConfig($event);
+    if($funcs) {
+      if (!is_array($funcs))
         $funcs = array($this -> config[$event]);
-      }
-      else {
-        $funcs = $this -> config[$event];
-      }
       foreach($funcs as $func) {
         if(function_exists($func)) {
-          if(!call_user_func_array($func,array(&$this))) {
+          if(!call_user_func_array($func, array(&$this))) {
             $return = false;
             LSerror :: addErrorCode('LSldapObject_07',array('func' => $func,'event' => $event));
           }
@@ -1744,7 +1760,7 @@ class LSldapObject {
    * 
    * @retval boolean True si tout c'est bien passé, false sinon
    **/
-  function fireObjectEvent($event) {
+  public function fireObjectEvent($event) {
     switch($event) {
       case 'after_create':
         return $this -> afterCreate();
@@ -1777,7 +1793,7 @@ class LSldapObject {
    * 
    * @retval mixed The value
    **/
-  function __get($key) {
+  public function __get($key) {
     if ($key=='subDnValue') {
       if (isset($this -> cache['subDnValue'])) {
         return $this -> cache['subDnValue'];
@@ -1793,8 +1809,9 @@ class LSldapObject {
       return $this -> cache['subDnName'];
     }
     elseif ($key=='rdn') {
-      if ($this -> config['rdn'] && isset($this -> attrs[ $this -> config['rdn'] ])) {
-        return $this -> attrs[ $this -> config['rdn'] ] -> getValue();
+      $rdn_attr = $this -> getConfig('rdn');
+      if ($rdn_attr && isset($this -> attrs[ $rdn_attr ])) {
+        return $this -> attrs[ $rdn_attr ] -> getValue();
       }
       return false;
     }
@@ -1805,11 +1822,12 @@ class LSldapObject {
    *
    * @retval mixed Array of valid IOformats of this object type
    **/
-  function listValidIOformats() {
+  public function listValidIOformats() {
     $ret=array();
-    if (isset($this -> config['ioFormat']) && is_array($this -> config['ioFormat'])) {
-      foreach($this -> config['ioFormat'] as $name => $conf) {
-        $ret[$name]=_((isset($conf['label'])?$conf['label']:$name));
+    $ioFormats = $this -> getConfig('ioFormat');
+    if (is_array($ioFormats)) {
+      foreach($ioFormats as $name => $conf) {
+        $ret[$name] = _((isset($conf['label'])?$conf['label']:$name));
       }
     }
     return $ret;
@@ -1822,13 +1840,23 @@ class LSldapObject {
    *
    * @retval boolean True if it's a valid IOformat, false otherwise
    **/
-  function isValidIOformat($f) {
-    if (isset($this -> config['ioFormat']) && is_array($this -> config['ioFormat']) && isset($this -> config['ioFormat'][$f])) {
-      return True;
-    }
-    return False;
+  public function isValidIOformat($f) {
+    return is_array($this -> getConfig("ioFormat.$f"));
   }
-  
+
+  /**
+   * Return a configuration parameter (or default value)
+   *
+   * @param[] $param	The configuration parameter
+   * @param[] $default	The default value (default : null)
+   * @param[] $cast	Cast resulting value in specific type (default : disabled)
+   *
+   * @retval mixed The configuration parameter value or default value if not set
+   **/
+  public function getConfig($param, $default=null, $cast=null) {
+    return LSconfig :: get($param, $default, $cast, $this -> config);
+  }
+
 }
 
 /**
@@ -1952,3 +1980,4 @@ _("LSldapObject : Error during generating container DN : %{error}")
 LSerror :: defineError('LSrelations_05',
 _("LSrelation : Some parameters are missing in the call of methods to handle standard relations (Method : %{meth}).")
 );
+
